.. :changelog:

History
-------

1.0.0 (2014-05-27)
++++++++++++++++++

* First stable release after gtting to 98% test coverage.

0.3.0 (2013-11-26)
++++++++++++++++++

* Support for automatic queryset optimization using select_related.

0.2.2 (2013-11-26)
++++++++++++++++++

* Added support for FK fields in tebles using the __ notation.

0.2.1 (2013-11-26)
++++++++++++++++++

* Included tag_parser for kwarg parsing in the coffee_table tag.

0.2.0 (2013-11-26)
++++++++++++++++++

* Improved documentation.

0.1.0 (2013-11-26)
++++++++++++++++++

* First release on PyPI.
